@@ -28,6 +28,7 @@ type UI interface {
 	ReadAnalysis(input io.Reader) error
 	SetIgnoreDirPaths(paths []string)
 	SetIgnoreDirPatterns(paths []string) error
+	SetIgnoreFromFile(ignoreFile string) error
 	SetIgnoreHidden(value bool)
 	StartUILoop() error
 }
@@ -39,6 +40,7 @@ type Flags struct {
 	OutputFile        string
 	IgnoreDirs        []string
 	IgnoreDirPatterns []string
+	IgnoreFromFile    string
 	MaxCores          int
 	ShowDisks         bool
 	ShowApparentSize  bool
@@ -48,6 +50,7 @@ type Flags struct {
 	NoProgress        bool
 	NoCross           bool
 	NoHidden          bool
+	Summarize         bool
 }
 
 // App defines the main application
@@ -107,6 +110,12 @@ func (a *App) Run() (err error) {
 		}
 	}
 
+	if a.Flags.IgnoreFromFile != "" {
+		if err = ui.SetIgnoreFromFile(a.Flags.IgnoreFromFile); err != nil {
+			return
+		}
+	}
+
 	if a.Flags.NoHidden {
 		ui.SetIgnoreHidden(true)
 	}
@@ -168,6 +177,7 @@ func (a *App) createUI() (UI, error) {
 			!a.Flags.NoColor && a.Istty,
 			!a.Flags.NoProgress && a.Istty,
 			a.Flags.ShowApparentSize,
+			a.Flags.Summarize,
 		)
 	} else {
 		ui = tui.CreateUI(
